==> web-cell-2.3.0-rc.1.tgz: package/source/utility/vDOM.ts <==
import type {
    SelfCloseTags,
    HTMLContentKeys,
    BaseHTMLProps,
    BaseSVGProps,
    HTMLProps,
    HTMLContainerProps,
    BaseEventHandlers,
    InputEventHandlers,
    BubbleEventHandlers
} from 'web-utility';
import { VNodeChildElement } from 'snabbdom/build/package/h';
import { WebCellComponent } from '../WebCell';

export interface WebCellData extends HTMLProps {
    key?: string | number;
    ref?: (node: Node) => void;
}

export type WebCellElement = VNodeChildElement | VNodeChildElement[];

export interface WebCellProps extends WebCellData {
    defaultSlot?: WebCellElement;
}

type BaseCellProps<T extends HTMLElement> = WebCellProps &
    BaseEventHandlers &
    Omit<BaseHTMLProps<T>, 'style' | HTMLContentKeys>;

type HTMLTags = {
    [tagName in keyof HTMLElementTagNameMap]: BaseCellProps<
        tagName extends 'input'
            ? Omit<HTMLElementTagNameMap['input'], 'list'> & { list?: string }
            : HTMLElementTagNameMap[tagName]
    > &
        (tagName extends 'input'
            ? InputEventHandlers
            : tagName extends SelfCloseTags
            ? {}
            : HTMLContainerProps & BubbleEventHandlers);
};

type SVGScalar<T extends Partial<SVGElement>> = {
    [K in keyof T]?: T[K] extends SVGAnimatedLength
        ? string
        : T[K] extends SVGAnimatedRect
        ? string
        : T[K] extends SVGAnimatedPreserveAspectRatio
        ? string
        : T[K];
};
type SVGTags = {
    [tagName in keyof SVGElementTagNameMap]: WebCellProps &
        SVGScalar<Omit<BaseSVGProps<SVGElementTagNameMap[tagName]>, 'style'>>;
};

declare global {
    namespace JSX {
        interface IntrinsicElements
            extends HTMLTags,
                Omit<SVGTags, 'a' | 'script' | 'style' | 'title'> {}

        interface ElementAttributesProperty {
            props: WebCellProps;
        }
        interface ElementChildrenAttribute {
            defaultSlot: VNodeChildElement[];
        }
        interface ElementClass extends WebCellComponent<any, any> {}
    }
}

export function Fragment({ defaultSlot }: WebCellProps) {
    return defaultSlot;
}

==> web-cell-2.4.0-rc.4.tgz: package/source/utility/vDOM.ts <==
import type {
    SelfCloseTags,
    HTMLContentKeys,
    BaseHTMLProps,
    BaseSVGProps,
    HTMLProps,
    HTMLContainerProps,
    BaseEventHandlers,
    InputEventHandlers,
    BubbleEventHandlers
} from 'web-utility';
import type { VNode } from 'snabbdom';

import { WebCellComponent } from '../WebCell';

export type { VNode } from 'snabbdom';

export interface WebCellData extends HTMLProps {
    key?: string | number;
    ref?: (node: Node) => void;
}

export type VNodeChildElement = number | string | VNode | null | undefined;

export type WebCellElement = VNodeChildElement | VNodeChildElement[];

export interface WebCellProps extends WebCellData {
    defaultSlot?: WebCellElement;
}

type BaseCellProps<T extends HTMLElement> = WebCellProps &
    BaseEventHandlers &
    Omit<BaseHTMLProps<T>, HTMLContentKeys>;

type HTMLTags = {
    [tagName in keyof HTMLElementTagNameMap]: BaseCellProps<
        HTMLElementTagNameMap[tagName]
    > &
        (tagName extends 'input'
            ? InputEventHandlers
            : tagName extends SelfCloseTags
            ? {}
            : HTMLContainerProps & BubbleEventHandlers);
};

type SVGTags = {
    [tagName in keyof SVGElementTagNameMap]: WebCellProps &
        BaseSVGProps<SVGElementTagNameMap[tagName]> &
        (tagName extends 'svg' ? { xmlns: string } : {});
};

declare global {
    namespace JSX {
        interface IntrinsicElements
            extends HTMLTags,
                Omit<SVGTags, 'a' | 'script' | 'style' | 'title'> {}

        interface ElementAttributesProperty {
            props: WebCellProps;
        }
        interface ElementChildrenAttribute {
            defaultSlot: VNodeChildElement[];
        }
        type ElementClass = WebCellComponent<any, any>;
    }
}

export function Fragment({ defaultSlot }: WebCellProps) {
    return defaultSlot;
}
